@@ -24,9 +24,12 @@ entitlement_retrieval <- function(
 ){
 
   identifier = match.arg(identifier)
+
+  id = gsub("SCOPUS_ID:", "", id, fixed = TRUE)
+  id = gsub("DOI:", "", id, fixed = TRUE)
   ender = paste0("/", paste(identifier, id, sep = "/"))
 
-  if (!is.null(http_end)){
+  if (!is.null(http_end)) {
     ender = paste(ender, http_end, sep = "/")
   }
 
